package cn.sh.stc.sict.theme.hphy.controller.web;


import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.DesensitizedUtil;
import cn.hutool.core.util.StrUtil;
import cn.sh.stc.sict.cloud.common.core.util.R;
import cn.sh.stc.sict.theme.hphy.model.HphyGuideMatch;
import cn.sh.stc.sict.theme.hphy.service.HphyGuideMatchService;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 导医推荐记录
 *
 * @author F_xh。
 * @date 2021-01-04 13:52:44
 */
@RestController
@RequestMapping("/hphyguidematch")
@AllArgsConstructor
@Slf4j
@Api(tags = "[B]导医推荐记录")
public class HphyGuideMatchController {

    private HphyGuideMatchService hphyGuideMatchService;

    /**
     * 分页查询
     *
     * @param page           分页对象
     * @return
     */
    @ApiOperation("分页查询 导医推荐记录")
    @GetMapping("/page")
    public R<HphyGuideMatch> getHphyGuideMatchPage(Page<HphyGuideMatch> page, HphyGuideMatch guide) {
        LambdaQueryWrapper<HphyGuideMatch> wrapper = Wrappers.lambdaQuery();
        wrapper.like(StrUtil.isNotBlank(guide.getPatientName()), HphyGuideMatch::getPatientName, guide.getPatientName())
                .like(StrUtil.isNotBlank(guide.getHospName()), HphyGuideMatch::getHospName, guide.getHospName())
                .like(StrUtil.isNotBlank(guide.getDeptName()), HphyGuideMatch::getDeptName, guide.getDeptName())
                .like(StrUtil.isNotBlank(guide.getDoctorName()), HphyGuideMatch::getDoctorName, guide.getDoctorName())
                .orderByDesc(HphyGuideMatch::getCreateTime);

        page = hphyGuideMatchService.page(page, wrapper);

        if(CollUtil.isNotEmpty(page.getRecords())){
            page.getRecords().forEach(i->{
                i.setPatientName(DesensitizedUtil.chineseName(i.getPatientName()));
            });
        }
        return new R(page);
    }
}
