package cn.sh.stc.sict.theme.hphy.service.impl;

import cn.sh.stc.sict.theme.hphy.dao.HpAppointmentMapper;
import cn.sh.stc.sict.theme.hphy.dao.HpStatisticsMapper;
import cn.sh.stc.sict.theme.hphy.service.HpStatisticsService;
import cn.sh.stc.sict.theme.hphy.vo.StatisticsUsageVO;
import lombok.AllArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

/**
 * 黄埔医导用户使用情况查询
 *
 * @author gao
 * @date 2023/01/06 11:04
 */
@Service("hpStatisticsService")
@AllArgsConstructor
public class HpStatisticsServiceImpl implements HpStatisticsService {

    @Autowired
    private final HpStatisticsMapper hpStatisticsMapper;

    @Autowired
    private final HpAppointmentMapper hpAppointmentMapper;

    /**
     * 获取使用情况概览统计信息
     *
     * @param startTime 开始时间
     * @param endTime   结束时间
     * @return
     */
    @Override
    public StatisticsUsageVO getUsageOverviewStatistics(String startTime, String endTime) {

        Long loginUserCount = hpStatisticsMapper.countLoginUser(startTime, endTime, null);
        Long newUserCount = hpStatisticsMapper.countNewUser(startTime, endTime);
        List<StatisticsUsageVO.HosUsageStatistics> hosUsageStatisticsList = hpStatisticsMapper.queryAppointmentUserGroupByHos(startTime, endTime);

        // 统计卫管中心数据
        Map<String, Long> hmcStatistics = hpStatisticsMapper.countHealthManagementCenter();
        Long hmcloginUserCount = hpStatisticsMapper.countLoginUser(startTime, endTime, "wx24c55f38b535cd96");
        hmcStatistics.put("卫管中心登录人数", hmcloginUserCount);
        return StatisticsUsageVO.builder()
                .newUserCount(newUserCount)
                .loginUserCount(loginUserCount)
                .hosAppointmentStatistics(hosUsageStatisticsList)
                .healthManagementCenterStatistics(hmcStatistics)
                .build();
    }
}
